pub struct StringSchema { /* private fields */ }Expand description
Schema for Redis string values, defining how to parse and convert them.
Redis strings are simple key-value pairs. This schema defines what type the values should be parsed as (e.g., Int64 for counters, Utf8 for text).
Example
ⓘ
use polars_redis::StringSchema;
use arrow::datatypes::DataType;
// For string counters
let schema = StringSchema::new(DataType::Int64)
.with_key(true)
.with_value_column_name("count");
// For text values
let schema = StringSchema::new(DataType::Utf8)
.with_key(true);Output Schema
_key(optional): The Redis keyvalue: The parsed value (type depends on schema)_ttl(optional): TTL in seconds
Implementations
Sourceimpl StringSchema
impl StringSchema
Sourcepub fn with_key_column_name(self, name: impl Into<String>) -> Self
pub fn with_key_column_name(self, name: impl Into<String>) -> Self
Set the name of the key column.
Sourcepub fn with_value_column_name(self, name: impl Into<String>) -> Self
pub fn with_value_column_name(self, name: impl Into<String>) -> Self
Set the name of the value column.
Sourcepub fn with_ttl_column_name(self, name: impl Into<String>) -> Self
pub fn with_ttl_column_name(self, name: impl Into<String>) -> Self
Set the name of the TTL column.
Sourcepub fn value_type(&self) -> &DataType
pub fn value_type(&self) -> &DataType
Get the value type.
Sourcepub fn include_key(&self) -> bool
pub fn include_key(&self) -> bool
Whether the key column is included.
Sourcepub fn key_column_name(&self) -> &str
pub fn key_column_name(&self) -> &str
Get the key column name.
Sourcepub fn value_column_name(&self) -> &str
pub fn value_column_name(&self) -> &str
Get the value column name.
Sourcepub fn include_ttl(&self) -> bool
pub fn include_ttl(&self) -> bool
Whether the TTL column is included.
Sourcepub fn ttl_column_name(&self) -> &str
pub fn ttl_column_name(&self) -> &str
Get the TTL column name.
Sourcepub fn to_arrow_schema(&self) -> Schema
pub fn to_arrow_schema(&self) -> Schema
Convert to Arrow Schema.